==> nextcloud-27.1.5.tgz: nextcloud/apps/comments/l10n/es_EC.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Comentaste",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Usted comentó en %1$s",
    "You commented on {file}" : "Hiciste un comentario de {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> de los archivos",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Fuiste mencionado en \"{file}\", en un comentario realizado por un usuario que ha sido eliminado",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} te mencionó en un comentario en \"{file}\"",
    "Files app plugin to add comments to files" : "Plugin de la aplicación de archivos para agregar comentarios a los archivos",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "Cancel edit" : "Cancelar edición",
    "Post comment" : "Publicar comentario",
    "No comments yet, start the conversation!" : "¡Aún no hay comentarios, inicia la conversación!",
    "No more messages" : "No hay más mensajes",
    "Retry" : "Reintentar",
    "Failed to mark comments as read" : "Error al marcar los comentarios como leídos",
    "Unable to load the comments list" : "No se puede cargar la lista de comentarios",
    "_1 new comment_::_{unread} new comments_" : ["1 comentario nuevo","{unread} comentarios nuevos","{unread} comentarios nuevos"],
    "Comment" : "Comentario",
    "An error occurred while trying to edit the comment" : "Ocurrió un error al intentar editar el comentario",
    "Comment deleted" : "Comentario eliminado",
    "An error occurred while trying to delete the comment" : "Ocurrió un error al intentar eliminar el comentario",
    "An error occurred while trying to create the comment" : "Ocurrió un error al intentar crear el comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer","%n comentarios sin leer"]
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/comments/l10n/es_EC.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Comentaste",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Usted comentó en %1$s",
    "You commented on {file}" : "Hiciste un comentario de {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> de los archivos",
    "Files" : "Archivo",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} te mencionó en un comentario en \"{file}\"",
    "Files app plugin to add comments to files" : "Plugin de la aplicación de archivos para agregar comentarios a los archivos",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "Cancel edit" : "Cancelar edición",
    "Post comment" : "Publicar comentario",
    "No comments yet, start the conversation!" : "¡Aún no hay comentarios, inicia la conversación!",
    "No more messages" : "No hay más mensajes",
    "Retry" : "Reintentar",
    "Failed to mark comments as read" : "Error al marcar los comentarios como leídos",
    "Unable to load the comments list" : "No se puede cargar la lista de comentarios",
    "_1 new comment_::_{unread} new comments_" : ["1 comentario nuevo","{unread} comentarios nuevos","{unread} comentarios nuevos"],
    "Comment" : "Comentario",
    "An error occurred while trying to edit the comment" : "Ocurrió un error al intentar editar el comentario",
    "Comment deleted" : "Comentario eliminado",
    "An error occurred while trying to delete the comment" : "Ocurrió un error al intentar eliminar el comentario",
    "An error occurred while trying to create the comment" : "Ocurrió un error al intentar crear el comentario"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
